@@ -214,7 +214,7 @@ class IxNetworkApi(Api):
         """Add an error to the global errors
         """
         if isinstance(error, str) is False:
-            self._errors.append(str(error))
+            self._errors.append('%s %s' % (type(error), str(error)))
         else:
             self._errors.append(error)
 
@@ -235,6 +235,11 @@ class IxNetworkApi(Api):
             self._traffic_item = self._ixnetwork.Traffic.TrafficItem
             if len(self._license_servers) > 0:
                 self._ixnetwork.Globals.Licensing.LicensingServers = self._license_servers
+            try:
+                version = pkg_resources.get_distribution("ixnetwork-open-traffic-generator").version
+            except Exception as e:
+                version = "ixnetwork-open-traffic-generator not installed using pip, unable to determine version"
+            self.info(version)
 
     def _request(self, method, url, payload=None):
         connection, url = self._assistant.Session._connection._normalize_url(
@@ -271,10 +276,22 @@ class IxNetworkApi(Api):
         if len(invalid_names) > 0:
             if ixn_obj._SDM_NAME == 'trafficItem':
                 # can't remove traffic items that are started
-                ixn_obj.find(Name='^(%s)$' % '|'.join(invalid_names), State='^start')
+                start_states = [
+                    'txStopWatchExpected', 
+                    'locked', 'started',
+                    'startedWaitingForStats', 
+                    'startedWaitingForStreams',
+                    'stoppedWaitingForStats']
+                for item in ixn_obj.find(Name='^(%s)$' % '|'.join(invalid_names)):
+                    if item.State in start_states:
+                        item.StopStatelessTraffic()
                 if len(ixn_obj) > 0:
-                    ixn_obj.StopStatelessTrafficBlocking()
-                    time.sleep(2)
+                    poll = True
+                    while poll:
+                        poll = False
+                        for v in self.select_traffic_items().values():
+                            if v['state'] not in ['error', 'stopped', 'unapplied']:
+                                poll = True
             ixn_obj.find(Name='^(%s)$' % '|'.join(invalid_names))
             if len(ixn_obj) > 0:
                 ixn_obj.remove()
