@@ -93,12 +93,16 @@ class Vport(object):
         for port in self._api.config.ports:
             if port.name not in vports.keys():
                 index = len(vports) + len(imports) + 1
-                imports.append({
+                vport_import = {
                     'xpath': '/vport[%i]' % index,
                     'name': port.name,
                     'rxMode': 'captureAndMeasure',
                     'txMode': 'interleaved'
-                })
+                }
+                location = getattr(port, 'location', None)
+                if location is None:
+                    vport_import['connectedTo'] = location
+                imports.append(vport_import)
         self._import(imports)
         for name, vport in self._api.select_vports().items():
             self._api.ixn_objects[name] = vport['href']
@@ -169,8 +173,9 @@ class Vport(object):
         add_addresses = []
         check_addresses = []
         for port in self._api.config.ports:
-            if port.location is not None and ';' in port.location:
-                chassis_address = port.location.split(';')[0]
+            location = getattr(port, 'location', None)
+            if location is not None and ';' in location:
+                chassis_address = location.split(';')[0]
                 chassis.find(Hostname='^(%s)$' % chassis_address)
                 if len(chassis) == 0:
                     add_addresses.append(chassis_address)
@@ -427,9 +432,9 @@ class Vport(object):
             pfc = flow_control.ieee_802_1qbb
             fcoe = {
                 'xpath':
-                vport['xpath'] + '/l1Config/' + vport['type'] + '/fcoe',
+                vport['xpath'] + '/l1Config/' + vport['type'].replace('Fcoe', '') + '/fcoe',
                 'enablePFCPauseDelay':
-                True,
+                False if pfc.pfc_delay == 0 else True,
                 'flowControlType':
                 Vport._FLOW_CONTROL_MAP[flow_control.choice],
                 'pfcPauseDelay':
